@@ -10,7 +10,7 @@
  * 
  * See http://www.troll.no/qpl for QPL licensing information.
  *
- * $Id: dbus_interface.h,v 1.2 2005/05/12 01:42:34 ro_han Exp $
+ * $Id: dbus_interface.h,v 1.3 2007/01/29 11:52:31 makoenig Exp $
  *****************************************************************************/
 
 // Some useful DBus functions.
@@ -21,4 +21,12 @@
 #include "common.h"
 
 void
-ivm_check_dbus_error(const DBusError * error);
+ivm_check_dbus_error(DBusError * error);
+
+void ivm_dbus_init();
+
+void *ivm_dbus_reinit();
+
+DBusHandlerResult ivm_dbus_signal_filter(DBusConnection *connection, DBusMessage *message, void *user_data);
+
+char *ivm_dbus_get_name_owner(const char *name);
