@@ -11,10 +11,12 @@
  * 
  * See http://www.troll.no/qpl for QPL licensing information.
  *
- * $Id: debug.c,v 1.9 2005/05/10 06:55:15 ro_han Exp $
+ * $Id: debug.c,v 1.13 2005/11/20 22:06:56 ro_han Exp $
  *****************************************************************************/
 
 #include <stdarg.h>
+#include <assert.h>
+#include <string.h>
 
 #include "debug.h"
 #include "log.h"
@@ -30,14 +32,18 @@ debug(const char *format, const char *file, const int line,
     va_start(app, func);
 
     if ((cfg_base == NULL)
-        || ((cfg_base->debug == TRUE) && (isdaemon == FALSE)))
+        || ((cfg_base->debug) && (!isdaemon)))
     {
         gchar *tmp = g_strdup_vprintf(format, app);
-
-        g_print("%s:%d (%s) %s\n", file, line, func, tmp);
+		assert(tmp != NULL);
+		
+        if (tmp[strlen(tmp)-1] == '\n')
+            g_print("%s:%d (%s) %s", file, line, func, tmp);
+        else
+            g_print("%s:%d (%s) %s\n", file, line, func, tmp);
         g_free(tmp);
-
-    } else if (cfg_base->debug == TRUE)
+    }
+    else if (cfg_base->debug)
     {
         log_vdebug(format, app);
     }
