@@ -11,7 +11,7 @@
  * 
  * See http://www.troll.no/qpl for QPL licensing information.
  *
- * $Id: manager.c,v 1.74 2006/04/18 04:20:23 ro_han Exp $
+ * $Id: manager.c,v 1.78 2007/01/29 11:52:31 makoenig Exp $
  ************************************************************************/
 
 #define _GNU_SOURCE
@@ -266,11 +266,11 @@ void set_mount_command()
 
     // Test if pmount-hal exists
     if ( usermode ) {
-        if ( !command_exists( "pmount-hal &> /dev/null" ) ) {
+        if ( !command_exists( "pmount-hal > /dev/null 2>&1" ) ) {
             DEBUG(_("pmount-hal was not found on your system.\n"));
         }
         else {
-            if ( !command_exists( "pumount &> /dev/null" ) ) {
+            if ( !command_exists( "pumount > /dev/null 2>&1" ) ) {
                 DEBUG(_("pmount-hal was found on your system, but pumount "
                         "wasn't!\n"));
             }
@@ -284,20 +284,33 @@ void set_mount_command()
                 return;
             }
         }
+        // Test if gnome-mount exists
+        if ( !command_exists( "gnome-mount > /dev/null 2>&1" ) ) {
+            DEBUG(_("gnome-mount was not found on your system.\n"));
+        }
+        else {
+            DEBUG(_
+                  ("gnome-mount was found on your system. It will be "
+                   "used for mounting.\n"));
+            known_mount_command = "gnome-mount -h '$hal.info.udi$'";
+            unknown_mount_command = known_mount_command;
+            umount_command = "gnome-mount -u -d '$hal.block.device$'";
+            return;
+        }
     }
     else {
         DEBUG(_
-              ("pmount-hal detection skipped, as we are a root instance "
-               "of Ivman.  pmount-hal is only used for user instances.\n"));
+              ("pmount-hal/gnome-mount detection skipped, as we are a root instance "
+               "of Ivman.  pmount-hal/gnome-mount is only used for user instances.\n"));
     }
 
 
     // Now try looking for regular pmount.
-    if ( !command_exists( "pmount &> /dev/null" ) ) {
+    if ( !command_exists( "pmount > /dev/null 2>&1" ) ) {
         DEBUG(_("pmount was not found on your system.\n"));
     }
     else {
-        if ( !command_exists( "pumount &> /dev/null" ) ) {
+        if ( !command_exists( "pumount > /dev/null 2>&1" ) ) {
             DEBUG(_
                   ("pmount was found on your system, but pumount "
                    "wasn't!\n"));
@@ -323,7 +336,7 @@ void set_mount_command()
                 g_string_append( pmount_umask_check, " --help | " );
             pmount_umask_check =
                 g_string_append( pmount_umask_check, GREP_PATH
-                                " -- '-u <' &> /dev/null");
+                                " -- '-u <' > /dev/null 2>&1");
 
             gboolean umask_accepted =
                 command_succeeds( pmount_umask_check->str );
@@ -366,12 +379,12 @@ void set_mount_command()
 
 
     // At the bottom of the barrel is plain old mount ...
-    if ( !command_exists( "mount &> /dev/null" ) ) {
+    if ( !command_exists( "mount > /dev/null 2>&1" ) ) {
         DEBUG(_("mount was not found on your system.\n"));
     }
 
     else {
-        if ( !command_exists( "umount &> /dev/null" ) ) {
+        if ( !command_exists( "umount > /dev/null 2>&1" ) ) {
             DEBUG(_
                   ("mount was found on your system, but umount was "
                    "not!\n"));
@@ -650,12 +663,17 @@ gboolean ivm_run_command(char const *const command,
             || libhal_device_property_exists(hal_ctx, udi,
                                              propertyname, &dbus_error))
         {
-            unsigned int type = execun ? psi_get_property_type(hal_ps,
-                                                               propertyname)
-                : libhal_device_get_property_type(hal_ctx,
+            unsigned int type;
+
+	    ivm_check_dbus_error(&dbus_error);
+
+	    type = execun ? psi_get_property_type(hal_ps,
+						  propertyname)
+		    : libhal_device_get_property_type(hal_ctx,
                                                   udi,
                                                   propertyname,
                                                   &dbus_error);
+	    ivm_check_dbus_error(&dbus_error);
 
             if (type == DBUS_TYPE_STRING)
             {
@@ -811,6 +829,7 @@ gboolean ivm_is_dvd(char const *const udi)
         libhal_device_get_property_string(hal_ctx, udi,
                                           "volume.mount_point",
                                           &dbus_error);
+    ivm_check_dbus_error(&dbus_error);
 
     if (!libhal_device_property_exists
         (hal_ctx, udi, "block.device", &dbus_error))
@@ -886,24 +905,31 @@ void ivm_device_mount(char const *const udi)
             udi,
             "block.storage_device",
             &dbus_error ) ) {
-            
+
+	    ivm_check_dbus_error(&dbus_error);
+
             char * parent_udi = libhal_device_get_property_string(
                 hal_ctx,
                 udi,
                 "block.storage_device",
                 &dbus_error);
+	    ivm_check_dbus_error(&dbus_error);
+
             if ( libhal_device_property_exists(
                 hal_ctx,
                 parent_udi,
                 "storage.policy.desired_mount_point",
                 &dbus_error) ) {
-                
+
+		ivm_check_dbus_error(&dbus_error);
+
                 char * mount_point = libhal_device_get_property_string(
                     hal_ctx,
                     parent_udi,
                     "storage.policy.desired_mount_point",
                     &dbus_error);
-                
+		ivm_check_dbus_error(&dbus_error);
+
                 GString * command = g_string_new( known_mount_command );
                 int strsize = strlen( "$hal.volume.policy.desired_mount_point$" );
                 int index =
@@ -959,12 +985,12 @@ void ivm_media_changed(char const *const udi)
     char *device = NULL;
 
     if (libhal_device_property_exists
-        (hal_ctx, udi, "block.device", &dbus_error))
+        (hal_ctx, udi, "block.device", NULL))
         device =
             (char *)
             libhal_device_get_property_string(hal_ctx,
                                               udi,
-                                              "block.device", &dbus_error);
+                                              "block.device", NULL);
 
     if (cfg->mount)
     {
@@ -980,10 +1006,10 @@ void ivm_media_changed(char const *const udi)
 
         if (libhal_device_property_exists(hal_ctx, udi,
                                           "volume.is_mounted",
-                                          &dbus_error)
+                                          NULL)
             && !libhal_device_get_property_bool(hal_ctx, udi,
                                                 "volume.is_mounted",
-                                                &dbus_error))
+                                                NULL))
         {
             DEBUG(_("Attempting to mount device %s\n"), device);
             ivm_device_mount(udi);
@@ -993,12 +1019,12 @@ void ivm_media_changed(char const *const udi)
 
     if ((!libhal_device_property_exists(hal_ctx, udi,
                                         "volume.is_mounted",
-                                        &dbus_error))
+                                        NULL))
         ||
         (!libhal_device_get_property_bool
-         (hal_ctx, udi, "volume.is_mounted", &dbus_error))
+         (hal_ctx, udi, "volume.is_mounted", NULL))
         ||
-        (!libhal_device_property_exists(hal_ctx, udi, "volume.mount_point", &dbus_error))
+        (!libhal_device_property_exists(hal_ctx, udi, "volume.mount_point", NULL))
        )
     {
         DEBUG(_("%s wasn't mounted, by us or by others..."), udi);
@@ -1014,7 +1040,7 @@ void ivm_media_changed(char const *const udi)
         char *mount_point = (char *)
             libhal_device_get_property_string(hal_ctx, udi,
                                               "volume.mount_point",
-                                              &dbus_error);
+                                              NULL);
 
         while (( !mount_point || (strlen(mount_point) < 2) )
                && (i < 5))
@@ -1023,7 +1049,7 @@ void ivm_media_changed(char const *const udi)
             mount_point = (char *)
                 libhal_device_get_property_string(hal_ctx, udi,
                                                   " volume.mount_point ",
-                                                  &dbus_error);
+                                                  NULL);
             i++;
         }
 
@@ -1398,8 +1424,23 @@ int main(int argc, char *argv[])
     parseArguments(argc, argv);
     do_startup_configure();
 
-    // Connect to HAL
-    setupHAL();
+    if (!g_thread_supported ())
+	g_thread_init (NULL);
+    dbus_g_thread_init ();
+
+    /* Setup DBus */
+    ivm_dbus_init();
+    if (dbus_connection != NULL) {
+	    /* If Hal is around */
+	    if ((ivm_dbus_get_name_owner("org.freedesktop.Hal")))
+		    hal_init();
+    } else {
+	    /* Try connecting to dbus */
+	    do {
+		    g_usleep (G_USEC_PER_SEC * 3);
+		    ivm_dbus_init();
+	    } while (dbus_connection == NULL);
+    }
 
     DEBUG("%s, http:/ivman.sourceforge.net\n", PACKAGE_STRING);
 
